@@ -1,8 +1,21 @@
-// arma_util.cpp: implementation of utility functions for extension of Armadillo
+//  arma_util.cpp: implementation of some utility functions for extension of
+//                 Armadillo library
+//  This file is part of jmcm.
 //
-// Copyright (C) 2015-2016 The University of Manchester
+//  Copyright (C) 2015-2016 Yi Pan <ypan1988@gmail.com>
 //
-// Written by Yi Pan - ypan1988@gmail.com
+//  This program is free software; you can redistribute it and/or modify
+//  it under the terms of the GNU General Public License as published by
+//  the Free Software Foundation; either version 2 of the License, or
+//  (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU General Public License for more details.
+//
+//  A copy of the GNU General Public License is available at
+//  https://www.R-project.org/Licenses/
 
 #include "arma_util.h"
 
@@ -119,4 +132,4 @@ arma::vec lvectorise(const arma::mat& X, bool diag, bool byrow) {
 
   return x;
 }
-}
+}  // namespace pan
